@@ -150,14 +150,7 @@ scarabee.new <- function(name = 'myanalysis',
       '# for the estimation',
       '  estim <- list(maxiter=500,',
       '                maxfunc=5000)',
-      ifelse(template=='dde',
-        paste('',
-              '# Please, provide DDE solver options',
-              '  dde.options <- list(dt=NULL,',
-              '                      hbsize=10000)',
-              '',
-              sep='\n'),
-        ''),
+      '',
       '# Please, enter the number of points per grid dimension and the dispersion',
       '# factor',
       '  npts <- 3',
@@ -166,24 +159,13 @@ scarabee.new <- function(name = 'myanalysis',
       '################################################################################',
       'require(scaRabee)',
       '',
-      ifelse(template=='dde',
-        paste('scarabee.analysis(files=files,',
-              '                  runtype=runtype,',
-              '                  method=method,',
-              '                  debugmode=debugmode,',
-              '                  estim.options=estim,',
-              '                  npts=npts,',
-              '                  alpha=alpha,',
-              '                  dde.options=dde.options)',
-              sep='\n'),
-        paste('scarabee.analysis(files=files,',
-              '                  runtype=runtype,',
-              '                  method=method,',
-              '                  debugmode=debugmode,',
-              '                  estim.options=estim,',
-              '                  npts=npts,',
-              '                  alpha=alpha)',
-              sep='\n')),
+      'scarabee.analysis(files=files,',
+      '                  runtype=runtype,',
+      '                  method=method,',
+      '                  debugmode=debugmode,',
+      '                  estim.options=estim,',
+      '                  npts=npts,',
+      '                  alpha=alpha)',
       '',
       'warnings()',
       'traceback()',sep='\n'),
