@@ -1,9 +1,8 @@
 
-.First.lib <- function(libname, pkgname) {
+.onLoad <- function(libname, pkgname) {
   require(lattice)
   require(grid)
   require(deSolve)
-  require(PBSddesolve)
   require(neldermead)
   require(utils)
 }
\ No newline at end of file
